@@ -1,4 +1,6 @@
-use crate::{Engine, EvalAltResult, Identifier, Module, ModuleResolver, Position, Shared};
+use crate::{
+    Engine, EvalAltResult, Identifier, Module, ModuleResolver, Position, Shared, SmartString,
+};
 #[cfg(feature = "no_std")]
 use std::prelude::v1::*;
 use std::{collections::BTreeMap, ops::AddAssign};
@@ -64,33 +66,23 @@ impl StaticModuleResolver {
     }
     /// Get an iterator of all the [modules][Module].
     #[inline(always)]
-    #[must_use]
     pub fn iter(&self) -> impl Iterator<Item = (&str, &Shared<Module>)> {
         self.0.iter().map(|(k, v)| (k.as_str(), v))
     }
     /// Get a mutable iterator of all the [modules][Module].
     #[inline(always)]
-    #[must_use]
     pub fn iter_mut(&mut self) -> impl Iterator<Item = (&str, &mut Shared<Module>)> {
         self.0.iter_mut().map(|(k, v)| (k.as_str(), v))
     }
-    /// Get a mutable iterator of all the modules.
-    #[inline(always)]
-    #[must_use]
-    pub fn into_iter(self) -> impl Iterator<Item = (Identifier, Shared<Module>)> {
-        self.0.into_iter()
-    }
     /// Get an iterator of all the [module][Module] paths.
     #[inline(always)]
-    #[must_use]
     pub fn paths(&self) -> impl Iterator<Item = &str> {
         self.0.keys().map(|s| s.as_str())
     }
     /// Get an iterator of all the [modules][Module].
     #[inline(always)]
-    #[must_use]
     pub fn values(&self) -> impl Iterator<Item = &Shared<Module>> {
-        self.0.values().map(|m| m)
+        self.0.values()
     }
     /// Remove all [modules][Module].
     #[inline(always)]
@@ -122,6 +114,15 @@ impl StaticModuleResolver {
     }
 }
 
+impl IntoIterator for StaticModuleResolver {
+    type Item = (Identifier, Shared<Module>);
+    type IntoIter = std::collections::btree_map::IntoIter<SmartString, Shared<Module>>;
+
+    fn into_iter(self) -> Self::IntoIter {
+        self.0.into_iter()
+    }
+}
+
 impl ModuleResolver for StaticModuleResolver {
     #[inline(always)]
     fn resolve(
