@@ -53,21 +53,27 @@ struct FnParam {
 
 impl PartialOrd for FnParam {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
-        Some(match self.name.partial_cmp(&other.name).unwrap() {
-            Ordering::Less => Ordering::Less,
-            Ordering::Greater => Ordering::Greater,
-            Ordering::Equal => match (self.typ.is_none(), other.typ.is_none()) {
-                (true, true) => Ordering::Equal,
-                (true, false) => Ordering::Greater,
-                (false, true) => Ordering::Less,
-                (false, false) => self
-                    .typ
-                    .as_ref()
-                    .unwrap()
-                    .partial_cmp(other.typ.as_ref().unwrap())
-                    .unwrap(),
+        Some(
+            match self
+                .name
+                .partial_cmp(&other.name)
+                .expect("String::partial_cmp should succeed")
+            {
+                Ordering::Less => Ordering::Less,
+                Ordering::Greater => Ordering::Greater,
+                Ordering::Equal => match (self.typ.is_none(), other.typ.is_none()) {
+                    (true, true) => Ordering::Equal,
+                    (true, false) => Ordering::Greater,
+                    (false, true) => Ordering::Less,
+                    (false, false) => self
+                        .typ
+                        .as_ref()
+                        .expect("`typ` is not `None`")
+                        .partial_cmp(other.typ.as_ref().expect("`typ` is not `None`"))
+                        .expect("String::partial_cmp should succeed"),
+                },
             },
-        })
+        )
     }
 }
 
@@ -157,7 +163,7 @@ impl From<&crate::module::FuncInfo> for FnMetadata {
                 {
                     info.func
                         .get_script_fn_def()
-                        .expect("never fails because the function is scripted")
+                        .expect("scripted function")
                         .comments
                         .to_vec()
                 }
@@ -201,6 +207,13 @@ struct ModuleMetadata {
     pub functions: Vec<FnMetadata>,
 }
 
+impl ModuleMetadata {
+    #[inline(always)]
+    pub fn new() -> Self {
+        Default::default()
+    }
+}
+
 impl From<&crate::Module> for ModuleMetadata {
     fn from(module: &crate::Module) -> Self {
         let mut functions: Vec<_> = module.iter_fn().map(|f| f.into()).collect();
@@ -233,11 +246,12 @@ impl Engine {
         include_global: bool,
     ) -> serde_json::Result<String> {
         let _ast = ast;
-        let mut global: ModuleMetadata = Default::default();
+        let mut global = ModuleMetadata::new();
 
         if include_global {
             self.global_modules
                 .iter()
+                .take(self.global_modules.len() - 1)
                 .flat_map(|m| m.iter_fn())
                 .for_each(|f| global.functions.push(f.into()));
         }
@@ -246,7 +260,7 @@ impl Engine {
             global.modules.insert(name.to_string(), m.as_ref().into());
         });
 
-        self.global_namespace
+        self.global_namespace()
             .iter_fn()
             .for_each(|f| global.functions.push(f.into()));
 
