@@ -247,10 +247,10 @@ fn test_get_set_chain_without_write_back() -> Result<(), Box<EvalAltResult>> {
         84
     );
 
-    engine.consume_with_scope(&mut scope, "print(outer.inner.value)")?;
+    engine.run_with_scope(&mut scope, "print(outer.inner.value)")?;
 
     #[cfg(not(feature = "no_index"))]
-    engine.consume_with_scope(&mut scope, "print(outer[0].value)")?;
+    engine.run_with_scope(&mut scope, "print(outer[0].value)")?;
 
     Ok(())
 }
